@@ -11,7 +11,7 @@
 *
 * LIC: GPL
 *
-* $Id: pppoe.h,v 1.28 2004/10/21 16:21:10 dfs Exp $
+* $Id: pppoe.h,v 1.31 2006/02/21 00:13:14 dfs Exp $
 *
 ***********************************************************************/
 
@@ -124,7 +124,7 @@ typedef unsigned int UINT32_t;
 #elif SIZEOF_UNSIGNED_LONG == 4
 typedef unsigned long UINT32_t;
 #else
-#error Could not find a 16-bit integer type
+#error Could not find a 32-bit integer type
 #endif
 
 #ifdef HAVE_LINUX_IF_ETHER_H
@@ -306,10 +306,13 @@ void fatalSys(char const *str);
 void rp_fatal(char const *str);
 void printErr(char const *str);
 void sysErr(char const *str);
+#ifdef DEBUGGING_ENABLED
 void dumpPacket(FILE *fp, PPPoEPacket *packet, char const *dir);
 void dumpHex(FILE *fp, unsigned char const *buf, int len);
+#endif
 int parsePacket(PPPoEPacket *packet, ParseFunc *func, void *extra);
 void parseLogErrs(UINT16_t typ, UINT16_t len, unsigned char *data, void *xtra);
+void pktLogErrs(char const *pkt, UINT16_t typ, UINT16_t len, unsigned char *data, void *xtra);
 void syncReadFromPPP(PPPoEConnection *conn, PPPoEPacket *packet);
 void asyncReadFromPPP(PPPoEConnection *conn, PPPoEPacket *packet);
 void asyncReadFromEth(PPPoEConnection *conn, int sock, int clampMss);
